@@ -745,6 +745,40 @@ cmd_after_startup (void)
         hook_execute (exec->hook);
 }
 
+
+cmd_state_t
+cmd_name_to_state (const char *name)
+{
+        if (! strcmp (name, "folder"))
+                return CMD_LIST;
+        if (! strcmp (name, "mail"))
+                return CMD_READ_MAIL;
+        if (! strcmp (name, "select"))
+                return CMD_SELECT_BOX;
+        if (! strcmp (name, "fetch"))
+                return CMD_FETCH;
+        if (! strcmp (name, "send"))
+                return CMD_SENDER;
+        if (! strcmp (name, "attach"))
+                return CMD_ATTACH;
+        if (! strcmp (name, "abook"))
+                return CMD_ABOOK;
+        if (! strcmp (name, "abook_add"))
+                return CMD_ABOOK_ADD;
+        if (! strcmp (name, "ask"))
+                return CMD_ASK;
+        if (! strcmp (name, "help"))
+                return CMD_HELP;
+        if (! strcmp (name, "read"))
+                return CMD_READ;
+        if (! strcmp (name, "debug"))
+                return CMD_DEBUG;
+        if (! strcmp (name, "search"))
+                return CMD_SEARCH;
+        return CMD_INVALID;
+}
+
+
 /****************************************************************************
  *    INTERFACE CLASS BODIES
  ****************************************************************************/
