@@ -280,6 +280,8 @@ put_mail_special (str_t *s, const char *fmt, mail_t *mail)
                                 str_put_char (s, 'r');
                         else if (mail->flags & FLAG_PASSED)
                                 str_put_char (s, 'f');
+                        else if (mail->flags & FLAG_BROKEN)
+                                str_put_char (s, '~');
                         else
                                 str_put_char (s, ' ');
                         break;
@@ -511,7 +513,7 @@ put_addr_desc_special (str_t *s, const char *fmt)
 
 
 static int
-put_key_special (str_t *s, const char *fmt, struct key *key, int meta)
+put_key_special (str_t *s, const char *fmt, struct _key *key, int meta)
 {
         struct fmt_seq fs;
 
@@ -785,7 +787,7 @@ substitute_addr_desc (const char *fmt, str_t *str)
 
 
 static char *
-substitute_key (const char *fmt, struct key *key, int meta)
+substitute_key (const char *fmt, struct _key *key, int meta)
 {
         str_t      *str = str_create ();
         int         fs_len;
@@ -917,7 +919,7 @@ eprintf_addr_desc (const char *fmt, str_t *str)
 
 
 char *
-eprintf_key (const char *fmt, struct key *key, int meta)
+eprintf_key (const char *fmt, struct _key *key, int meta)
 {
         char *result;
 
