@@ -169,7 +169,7 @@ add_tree (WINDOW *window, mail_t *mail, int maxlen)
 
 
 static int
-add_string (WINDOW *win, char *str, int maxlen, search_t *search)
+add_string (WINDOW *win, unsigned char *str, int maxlen, search_t *search)
 {
         int pos = -1;
         int len = 1;
@@ -571,7 +571,7 @@ match_subject (search_t *search, int index)
         if (mail->subject == NULL)
                 return 0;
         
-        if (search_perform (search, mail->subject) != -1)
+        if (search_perform (search, (unsigned char *) mail->subject) != -1)
                 return 1;
 
         return 0;
@@ -592,7 +592,7 @@ match_from (search_t *search, int index)
         if (mail->from == NULL || mail->from->full == NULL)
                 return 0;
 
-        if (search_perform (search, mail->from->full) != -1)
+        if (search_perform (search, (unsigned char *) mail->from->full) != -1)
                 return 1;
 
         return 0;
