@@ -284,18 +284,16 @@ add_mail (const char *fname, const char *dir)
                 return;
         }
 
-        ret = mlex_scan_file (0);
-        if (ret == NEXT_MAIL){
-                newmail->flags           |= mail_flags (fname, dir, dname_len);
-                newmail->type             = BOX_MAILDIR;
-                newmail->place.file_name  = full_name;
-                newmail->mime->file       = full_name;
-                mail_array_insert (new_marray, newmail);
-        }
-        else {
+        ret = mlex_scan_file (0, 0);
+        if (ret != NEXT_MAIL){
                 error_ (0, _("%s has bad format"), fname);
-                xfree (full_name);
+                newmail->flags   |= FLAG_BROKEN;
         }
+        newmail->flags           |= mail_flags (fname, dir, dname_len);
+        newmail->type             = BOX_MAILDIR;
+        newmail->place.file_name  = full_name;
+        newmail->mime->file       = full_name;
+        mail_array_insert (new_marray, newmail);
 
         fclose (yyin);
 }
