@@ -672,8 +672,10 @@ mailreader_load (void)
 void
 mailreader_show (void)
 {
-        if (load_mail ())
+        if (load_mail ()){
+                window_hide (mail_select->win);
                 return;
+        }
         
         window_show (mail_select->win);
 }
