@@ -935,10 +935,13 @@ mime_post_setup (void)
                               xstrdup ("elmo-pgp"));
 
         register_new_type (xstrdup ("text/plain"),
-                           "(\\.txt$)|(README)|(\\.diff$)|(\\.asc$)"
-                           "|(\\.[ch]$)|(\\.cpp$)|(\\.cc$)|(\\.java$)"
-                           "|(\\.sh$)|(\\.tex$)|(\\.pl$)|(\\.po$)"
+                           "(\\.txt$)|(README)|(\\.diff$)|(\\.asc$)|(\\.po$)"
                            "|(\\.dsc$)");
+        register_new_type (xstrdup ("text/x-c"), "(\\.[Cchly]$)|(\\.ccp?$)");
+        register_new_type (xstrdup ("text/x-java"), "\\.java$");
+        register_new_type (xstrdup ("text/x-tex"), "\\.tex$");
+        register_new_type (xstrdup ("text/x-perl"), "\\.pl$");
+        register_new_type (xstrdup ("text/x-sh"), "\\.sh$");
         register_new_type (xstrdup ("text/html"), "\\.[dsx]?html?$");
         register_new_type (xstrdup ("text/rtf"), "\\.rtf$");
         register_new_type (xstrdup ("text/xml"), "\\.x[ms]l$");
@@ -952,6 +955,7 @@ mime_post_setup (void)
         register_new_type (xstrdup ("audio/mpeg"),
                            "(\\.mp[23]$)|(\\.mpe?ga$)");
         register_new_type (xstrdup ("audio/midi"), "\\.midi?$");
+        register_new_type (xstrdup ("audio/x-wav"), "\\.wave?$");
         register_new_type (xstrdup ("video/mpeg"), "\\.mp[eg]g?$");
 }
 
@@ -1108,6 +1112,7 @@ mime_decode_utf8 (char *str)
         s.inter   = NULL;
         s.charset = xstrdup ("utf-8");
         s.inter   = str_dup (str);
+        s.result  = NULL;
 
         get_result (& s);
 
