@@ -123,7 +123,7 @@
 enum state {
         POP_DISCONNECTED,       // no connection
         POP_IDLE,               // accepting commands
-        POP_PROCESSING,         // processing command
+        POP_PROCESSING          // processing command
 };
 
 
@@ -137,7 +137,7 @@ enum op_mode {
         FETCH_DEL,
         FETCH_ALL,
         DELETE_ALL,
-        FETCH_DEL_ALL,
+        FETCH_DEL_ALL
 };
 
 
@@ -147,7 +147,7 @@ enum command {
         C_FETCH,                // retrieve selected message
         C_DELETE,               // delete selected message
         C_RESET,                // reset connection state
-        C_DISCONNECT,           // disconnect
+        C_DISCONNECT            // disconnect
 };
 
 
@@ -167,7 +167,7 @@ enum stage {
         S_RSET,
         S_STAT,
         S_LIST,
-        S_TOP,
+        S_TOP
 };
 
 /****************************************************************************
@@ -586,6 +586,8 @@ Pop::next_action_fetch (void)
 
                 case S_LIST:
                         mail_index = 0;
+                        if (maildrop_count > 0)
+                                found_new_mail = true;
                 case S_RETR:
                         retrieve_next_message ();
                         break;
@@ -670,6 +672,8 @@ Pop::next_action_fetch_dele (void)
 
                 case S_LIST:
                         mail_index = 0;
+                        if (maildrop_count > 0)
+                                found_new_mail = true;
                 case S_RETR:
                         fetch_del_next_message ();
                         break;
@@ -1142,10 +1146,22 @@ Pop::on_shutdown (void)
                         cleanup ();
                         break;
 
-                case CHECK_NEW:
                 case FETCH_ALL:
-                case DELETE_ALL:
                 case FETCH_DEL_ALL:
+                        ask = ask_select_next (ask);
+                        if (ask){
+                                stage = S_QUIT;
+                                next_action ();
+                        }
+                        else {
+                                if (found_new_mail)
+                                        run_sound ();
+                                cleanup ();
+                        }
+                        break;
+
+                case DELETE_ALL:
+                case CHECK_NEW:
                         ask = ask_select_next (ask);
                         if (ask){
                                 stage = S_QUIT;
@@ -1155,6 +1171,7 @@ Pop::on_shutdown (void)
                                 cleanup ();
                         }
                         break;
+
         }
 }
 
@@ -1619,8 +1636,9 @@ Pop::fetch (void)
         if (ask == NULL)
                 return;
 
-        state = POP_PROCESSING;
-        mode  = FETCH;
+        state          = POP_PROCESSING;
+        mode           = FETCH;
+        found_new_mail = false;
         connect ();
 }
 
@@ -1657,8 +1675,9 @@ Pop::fetch_purge (void)
         if (ask == NULL)
                 return;
 
-        state = POP_PROCESSING;
-        mode  = FETCH_DEL;
+        state          = POP_PROCESSING;
+        mode           = FETCH_DEL;
+        found_new_mail = false;
         connect ();
 }
 
@@ -1678,8 +1697,9 @@ Pop::fetch_all (void)
                 return;
         }
 
-        state = POP_PROCESSING;
-        mode  = FETCH_ALL;
+        state          = POP_PROCESSING;
+        mode           = FETCH_ALL;
+        found_new_mail = false;
         connect ();
 }
 
@@ -1720,8 +1740,9 @@ Pop::fetch_purge_all (void)
                 return;
         }
 
-        state = POP_PROCESSING;
-        mode  = FETCH_DEL_ALL;
+        state          = POP_PROCESSING;
+        mode           = FETCH_DEL_ALL;
+        found_new_mail = false;
         connect ();
 }
 
