@@ -606,14 +606,15 @@ complete (void)
                 xfree (compl_string);
                 compl_string = NULL;
         }
-        else if (compl_items){
-                fprintf (stderr, "%c", '\a');
+        else if (compl_items && compl_items->count > 0){
+                BEEP ();
                 len = longest_common_prefix (compl_items);
                 replace (compl_items->array[0], len);
                 tab = 1;
         }
         else {
                 BEEP ();
+                tab = 0;
         }
 }
 
@@ -764,9 +765,12 @@ read_accept (void)
   
         if (tab){
                 index = choose_index ();
-                replace (compl_items->array[index],
-                         strlen (compl_items->array[index]));
-                leave_choose ();
+                if (index != -1){
+                        replace (compl_items->array[index],
+                                 strlen (compl_items->array[index]));
+                        leave_choose ();
+                }
+                accept = 1;
         }
         else {
                 accept = 1;
