@@ -569,8 +569,10 @@ sender_open_new_to (char *to)
         char *file;
 
         sender_ask = ask_select_default ("smtp_acc");
-        if (sender_ask == NULL)
+        if (sender_ask == NULL){
+                error_ (0, _("No SMTP account defined."));
                 return;
+        }
 
         file = compose_new (to);
 
@@ -599,8 +601,10 @@ sender_open_reply (void)
         char *file;
 
         sender_ask = ask_select_default ("smtp_acc");
-        if (sender_ask == NULL)
+        if (sender_ask == NULL){
+                error_ (0, _("No SMTP account defined."));
                 return;
+        }
   
         file = compose_reply (0);
 
@@ -621,8 +625,10 @@ sender_open_reply_all (void)
         char *file;
 
         sender_ask = ask_select_default ("smtp_acc");
-        if (sender_ask == NULL)
+        if (sender_ask == NULL){
+                error_ (0, _("No SMTP account defined."));
                 return;
+        }
   
         file = compose_reply (1);
 
@@ -644,8 +650,10 @@ sender_open_fwd (void)
         char *file;
 
         sender_ask = ask_select_default ("smtp_acc");
-        if (sender_ask == NULL)
+        if (sender_ask == NULL){
+                error_ (0, _("No SMTP account defined."));
                 return;
+        }
   
         file = compose_fwd (NULL);
 
@@ -666,8 +674,10 @@ sender_open_edit (void)
         char *file;
 
         sender_ask = ask_select_default ("smtp_acc");
-        if (sender_ask == NULL)
+        if (sender_ask == NULL){
+                error_ (0, _("No SMTP account defined."));
                 return;
+        }
 
         file = compose_edit ();
 
