@@ -76,14 +76,14 @@ enum state {
         SMTP_DATA,              /* after response to data */
         SMTP_SENT,              /* after response to message */
 
-        SMTP_QUIT,              /* after response to quit */
+        SMTP_QUIT               /* after response to quit */
 };
 
 enum auth {
         AUTH_NONE,              /* authentication not supported */
         AUTH_CRAM_MD5,          /* CRAM-MD5 */
         AUTH_PLAIN,             /* PLAIN */
-        AUTH_LOGIN,             /* LOGIN */
+        AUTH_LOGIN              /* LOGIN */
 };
 
 /****************************************************************************
